/*

Generation Ships.js

Script for randomly spawning Generation Ships.


Oolite
Copyright © 2003-2011 Giles C Williams and contributors

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
MA 02110-1301, USA.


Generation Ships.oxp
Copyright © 2006-2011 "Draco_Caeles" & "Commander McLane"

This work is licensed under the Creative Commons
Attribution-Noncommercial-Share Alike 3.0 Unported License.

To view a copy of this license, visit
http://creativecommons.org/licenses/by-nc-sa/3.0/ or send a letter
to Creative Commons, 171 Second Street, Suite 300, San Francisco,
California, 94105, USA.

*/

"use strict";
this.name = "Generation Ships";
this.description = "Script for randomly spawning Generation Ships";
this.author = "Commander McLane";
this.copyright = "© 2011 Commander McLane";
this.license = "CC-BY-NC-SA 3.0";
this.version = "1.5.0";

//-------------------------------------------------------------------------------------------------------------
this.startUpComplete = function () {
	if (worldScripts.BountySystem_Core) {
		var bsc = worldScripts.BountySystem_Core;
		bsc._offenceTypes["generation ship"] = {
			description: "Interference with and/or damage to a Generation Ship in open Interstellar Space",
			severity: 3
		};
	}
}

//-------------------------------------------------------------------------------------------------------------
this.interstellarSpaceWillPopulate = function () {
	var position = Vector3D(0, 0, 0);
	system.setPopulator("gen ship", {
		callback: function (pos) {
			var chance = 0.01;
			for (var i = 1; i <= 30; i++) {
				if (Math.random() < chance) {
					system.addShips("generationship-" + i.toString(), 1, pos, 250000);
					break;
				}
			}
		}.bind(this),
		location: "COORDINATES",
		coordinates: position
	});

}

//-------------------------------------------------------------------------------------------------------------
this.missionScreenOpportunity = function () {

	if (player.ship.docked && player.ship.dockedStation.hasRole("generationship") && (missionVariables.genship == "PLAYER_ATTACKED" || missionVariables.genship == "PLAYER_DOCKED")) {
		// build message
		var msg = "";
		if (missionVariables.genship == "PLAYER_ATTACKED") msg = expandMissionText("genship_penalty");
		if (missionVariables.genship == "PLAYER_DOCKED") msg = expandMissionText("genship_dock_penalty");

		mission.runScreen({
			title: "Galactic Court",
			message: "---INCOMING MESSAGE\n\n" + msg + "\n\n---MESSAGE ENDS",
			model: "generationship"
		});

		player.ship.setBounty(player.ship.bounty + 51, "generation ship");
		player.credits -= 25000;
		if (player.credits < 0) player.credits = 0;
		delete missionVariables.genship;

		// send as email message, if system is installed.
		var w = worldScripts.EmailSystem;
		if (w) {
			w.$createEmail({
				sender: "Galactic Court",
				subject: "Generation Ship Penalty",
				date: global.clock.seconds,
				message: msg
			});
		}
	}
}

//-------------------------------------------------------------------------------------------------------------
// if the player docks, hide the F3 screen from them.
this.guiScreenChanged = function (to, from) {
	if (player.ship.docked) {
		if (player.ship.dockedStation.hasRole("generationship")) {
			if (guiScreen === "GUI_SCREEN_EQUIP_SHIP") {
				mission.runScreen({
					title: "Generation Ship",
					message: "There is no equipment available for your vessel on a Generation Ship."
				});
			}
			if (guiScreen === "GUI_SCREEN_MARKET") {
				mission.runScreen({
					title: "Generation Ship",
					message: "There is no market available on a Generation Ship."
				});
			}
		}
	}
}